/*
 * NoScript Commons Library
 * Reusable building blocks for cross-browser security/privacy WebExtensions.
 * Copyright (C) 2020-2023 Giorgio Maone <https://maone.net>
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <https://www.gnu.org/licenses/>.
 */

"use strict";
/**
 * Creates a RegExp object by joining an arbitrary number of strings or RegExp objects and merging the flags
 * @param  {...any} regExps RegExp objects or strings representing ordered parts of the resulting RegExp
 * @returns A new RegExp resulting by joining args (or their @source property, for RegExp ones) and merging the flags of each.
 */
RegExp.combo = (...regExps) => {
  const flags = new Set();
  const parts = [];
  for (let rx of regExps) {
    if (rx instanceof RegExp) {
      parts.push(rx.source);
      flags.add(rx.flags);
    } else {
      parts.push(rx);
    }
  }
  return new RegExp(parts.join(''), [...flags].join(''));
}